searchData={"items":[{"type":"module","title":"QlikElixir","doc":"An Elixir client library for uploading CSV files to Qlik Cloud.","ref":"QlikElixir.html"},{"type":"module","title":"Installation - QlikElixir","doc":"Add `qlik_elixir` to your list of dependencies in `mix.exs`:\n\n    def deps do\n      [\n        {:qlik_elixir, \"~> 0.1.0\"}\n      ]\n    end","ref":"QlikElixir.html#module-installation"},{"type":"module","title":"Configuration - QlikElixir","doc":"Configure the client using environment variables:\n\n    export QLIK_API_KEY=\"your-api-key\"\n    export QLIK_TENANT_URL=\"https://your-tenant.qlikcloud.com\"\n    export QLIK_CONNECTION_ID=\"your-connection-id\"  # Optional\n\nOr configure in your application config:\n\n    config :qlik_elixir,\n      api_key: \"your-api-key\",\n      tenant_url: \"https://your-tenant.qlikcloud.com\",\n      connection_id: \"your-connection-id\"","ref":"QlikElixir.html#module-configuration"},{"type":"module","title":"Usage - QlikElixir","doc":"# Upload a file\n    {:ok, %{\"id\" => file_id}} = QlikElixir.upload_csv(\"data.csv\")\n\n    # Upload with options\n    QlikElixir.upload_csv(\"data.csv\",\n      name: \"custom_name.csv\",\n      connection_id: \"space-123\",\n      overwrite: true\n    )\n\n    # Upload content directly\n    csv_content = \"header1,header2\\nvalue1,value2\"\n    QlikElixir.upload_csv_content(csv_content, \"dynamic.csv\")\n\n    # List files\n    {:ok, files} = QlikElixir.list_files()\n\n    # Check if file exists\n    QlikElixir.file_exists?(\"data.csv\")\n\n    # Delete a file\n    QlikElixir.delete_file(\"file-id-123\")","ref":"QlikElixir.html#module-usage"},{"type":"function","title":"QlikElixir.delete_file/2","doc":"Deletes a file by ID.","ref":"QlikElixir.html#delete_file/2"},{"type":"function","title":"Examples - QlikElixir.delete_file/2","doc":"iex> QlikElixir.delete_file(\"file-123\")\n    :ok\n\n    iex> QlikElixir.delete_file(\"non-existent\")\n    {:error, %QlikElixir.Error{type: :file_not_found}}","ref":"QlikElixir.html#delete_file/2-examples"},{"type":"function","title":"QlikElixir.file_exists?/2","doc":"Checks if a file exists by name.","ref":"QlikElixir.html#file_exists?/2"},{"type":"function","title":"Examples - QlikElixir.file_exists?/2","doc":"iex> QlikElixir.file_exists?(\"data.csv\")\n    true\n\n    iex> QlikElixir.file_exists?(\"non-existent.csv\")\n    false","ref":"QlikElixir.html#file_exists?/2-examples"},{"type":"function","title":"QlikElixir.find_file_by_name/2","doc":"Finds a file by name.","ref":"QlikElixir.html#find_file_by_name/2"},{"type":"function","title":"Examples - QlikElixir.find_file_by_name/2","doc":"iex> QlikElixir.find_file_by_name(\"data.csv\")\n    {:ok, %{\"id\" => \"file-123\", \"name\" => \"data.csv\", \"size\" => 1024}}\n\n    iex> QlikElixir.find_file_by_name(\"non-existent.csv\")\n    {:error, %QlikElixir.Error{type: :file_not_found}}","ref":"QlikElixir.html#find_file_by_name/2-examples"},{"type":"function","title":"QlikElixir.list_files/1","doc":"Lists uploaded files.","ref":"QlikElixir.html#list_files/1"},{"type":"function","title":"Options - QlikElixir.list_files/1","doc":"* `:limit` - Maximum number of files to return (default: 100)\n  * `:offset` - Number of files to skip (default: 0)\n  * `:config` - Custom configuration (overrides defaults)","ref":"QlikElixir.html#list_files/1-options"},{"type":"function","title":"Examples - QlikElixir.list_files/1","doc":"iex> QlikElixir.list_files()\n    {:ok, %{\n      \"data\" => [\n        %{\"id\" => \"file-123\", \"name\" => \"data.csv\", \"size\" => 1024},\n        %{\"id\" => \"file-456\", \"name\" => \"users.csv\", \"size\" => 2048}\n      ],\n      \"total\" => 2\n    }}\n\n    iex> QlikElixir.list_files(limit: 10, offset: 20)\n    {:ok, %{\"data\" => [%{\"id\" => \"file-789\", \"name\" => \"logs.csv\", \"size\" => 512}], \"total\" => 50}}","ref":"QlikElixir.html#list_files/1-examples"},{"type":"function","title":"QlikElixir.new_config/1","doc":"Creates a new configuration struct.\n\nThis is useful when you need to work with multiple Qlik tenants or want to\noverride the default configuration.","ref":"QlikElixir.html#new_config/1"},{"type":"function","title":"Examples - QlikElixir.new_config/1","doc":"iex> config = QlikElixir.Config.new(\n    ...>   api_key: \"different-key\",\n    ...>   tenant_url: \"https://other-tenant.qlikcloud.com\"\n    ...> )\n    iex> QlikElixir.upload_csv(\"data.csv\", config: config)","ref":"QlikElixir.html#new_config/1-examples"},{"type":"function","title":"QlikElixir.upload_csv/2","doc":"Uploads a CSV file from a file path.","ref":"QlikElixir.html#upload_csv/2"},{"type":"function","title":"Options - QlikElixir.upload_csv/2","doc":"* `:name` - Custom filename for the upload (defaults to original filename)\n  * `:connection_id` - Qlik connection ID (overrides configured default)\n  * `:overwrite` - Whether to overwrite existing files (default: false)\n  * `:config` - Custom configuration (overrides defaults)","ref":"QlikElixir.html#upload_csv/2-options"},{"type":"function","title":"Examples - QlikElixir.upload_csv/2","doc":"iex> QlikElixir.upload_csv(\"data.csv\")\n    {:ok, %{\"id\" => \"file-123\", \"name\" => \"data.csv\", \"size\" => 1024}}\n\n    iex> QlikElixir.upload_csv(\"data.csv\", name: \"renamed.csv\", overwrite: true)\n    {:ok, %{\"id\" => \"file-456\", \"name\" => \"renamed.csv\", \"size\" => 1024}}","ref":"QlikElixir.html#upload_csv/2-examples"},{"type":"function","title":"QlikElixir.upload_csv_content/3","doc":"Uploads CSV content directly.","ref":"QlikElixir.html#upload_csv_content/3"},{"type":"function","title":"Options - QlikElixir.upload_csv_content/3","doc":"* `:connection_id` - Qlik connection ID (overrides configured default)\n  * `:overwrite` - Whether to overwrite existing files (default: false)\n  * `:config` - Custom configuration (overrides defaults)","ref":"QlikElixir.html#upload_csv_content/3-options"},{"type":"function","title":"Examples - QlikElixir.upload_csv_content/3","doc":"iex> content = \"id,name\\n1,John\\n2,Jane\"\n    iex> QlikElixir.upload_csv_content(content, \"users.csv\")\n    {:ok, %{\"id\" => \"file-789\", \"name\" => \"users.csv\", \"size\" => 28}}","ref":"QlikElixir.html#upload_csv_content/3-examples"},{"type":"module","title":"QlikElixir.Client","doc":"HTTP client wrapper for Qlik API interactions.","ref":"QlikElixir.Client.html"},{"type":"function","title":"QlikElixir.Client.delete/3","doc":"Makes a DELETE request to the Qlik API.","ref":"QlikElixir.Client.html#delete/3"},{"type":"function","title":"QlikElixir.Client.get/3","doc":"Makes a GET request to the Qlik API.","ref":"QlikElixir.Client.html#get/3"},{"type":"function","title":"QlikElixir.Client.post/4","doc":"Makes a POST request to the Qlik API.","ref":"QlikElixir.Client.html#post/4"},{"type":"module","title":"QlikElixir.Config","doc":"Configuration management for QlikElixir.\n\nSupports configuration through:\n- Environment variables: QLIK_API_KEY, QLIK_TENANT_URL, QLIK_CONNECTION_ID\n- Runtime configuration\n- Application configuration","ref":"QlikElixir.Config.html"},{"type":"function","title":"QlikElixir.Config.base_url/1","doc":"Gets the base URL for API requests.","ref":"QlikElixir.Config.html#base_url/1"},{"type":"function","title":"QlikElixir.Config.default/0","doc":"Gets the default configuration.","ref":"QlikElixir.Config.html#default/0"},{"type":"function","title":"QlikElixir.Config.headers/1","doc":"Gets the headers for API requests.","ref":"QlikElixir.Config.html#headers/1"},{"type":"function","title":"QlikElixir.Config.merge/2","doc":"Merges configuration options with defaults.","ref":"QlikElixir.Config.html#merge/2"},{"type":"function","title":"QlikElixir.Config.new/1","doc":"Creates a new configuration struct.","ref":"QlikElixir.Config.html#new/1"},{"type":"function","title":"Examples - QlikElixir.Config.new/1","doc":"iex> config = QlikElixir.Config.new(api_key: \"key\", tenant_url: \"https://tenant.qlikcloud.com\")\n    iex> config.api_key\n    \"key\"\n    iex> config.tenant_url\n    \"https://tenant.qlikcloud.com\"","ref":"QlikElixir.Config.html#new/1-examples"},{"type":"type","title":"QlikElixir.Config.t/0","doc":"","ref":"QlikElixir.Config.html#t:t/0"},{"type":"function","title":"QlikElixir.Config.validate/1","doc":"Validates a configuration struct.\n\nReturns {:ok, config} if valid, or {:error, reason} if invalid.","ref":"QlikElixir.Config.html#validate/1"},{"type":"module","title":"QlikElixir.Error","doc":"Custom error types for QlikElixir operations.","ref":"QlikElixir.Error.html"},{"type":"function","title":"QlikElixir.Error.authentication_error/2","doc":"Creates an authentication error.","ref":"QlikElixir.Error.html#authentication_error/2"},{"type":"function","title":"QlikElixir.Error.configuration_error/2","doc":"Creates a configuration error.","ref":"QlikElixir.Error.html#configuration_error/2"},{"type":"type","title":"QlikElixir.Error.error_type/0","doc":"","ref":"QlikElixir.Error.html#t:error_type/0"},{"type":"function","title":"QlikElixir.Error.file_exists_error/2","doc":"Creates a file exists error.","ref":"QlikElixir.Error.html#file_exists_error/2"},{"type":"function","title":"QlikElixir.Error.file_not_found/2","doc":"Creates a file not found error.","ref":"QlikElixir.Error.html#file_not_found/2"},{"type":"function","title":"QlikElixir.Error.file_too_large/2","doc":"Creates a file too large error.","ref":"QlikElixir.Error.html#file_too_large/2"},{"type":"function","title":"QlikElixir.Error.network_error/2","doc":"Creates a network error.","ref":"QlikElixir.Error.html#network_error/2"},{"type":"function","title":"QlikElixir.Error.new/3","doc":"Creates a new error with the given type and message.","ref":"QlikElixir.Error.html#new/3"},{"type":"type","title":"QlikElixir.Error.t/0","doc":"","ref":"QlikElixir.Error.html#t:t/0"},{"type":"function","title":"QlikElixir.Error.unknown_error/2","doc":"Creates an unknown error.","ref":"QlikElixir.Error.html#unknown_error/2"},{"type":"function","title":"QlikElixir.Error.upload_error/2","doc":"Creates an upload error.","ref":"QlikElixir.Error.html#upload_error/2"},{"type":"function","title":"QlikElixir.Error.validation_error/2","doc":"Creates a validation error.","ref":"QlikElixir.Error.html#validation_error/2"},{"type":"module","title":"QlikElixir.Uploader","doc":"Core upload logic for CSV files to Qlik Cloud.","ref":"QlikElixir.Uploader.html"},{"type":"function","title":"QlikElixir.Uploader.upload_content/4","doc":"Uploads CSV content directly.","ref":"QlikElixir.Uploader.html#upload_content/4"},{"type":"function","title":"QlikElixir.Uploader.upload_file/3","doc":"Uploads a CSV file from a file path.","ref":"QlikElixir.Uploader.html#upload_file/3"},{"type":"extras","title":"QlikElixir","doc":"# QlikElixir\n\nAn Elixir client library for uploading CSV files to Qlik Cloud with comprehensive API support.","ref":"readme.html"},{"type":"extras","title":"Features - QlikElixir","doc":"- Upload CSV files to Qlik Cloud using multipart form data\n- Support for both file path and binary content uploads\n- Automatic overwrite handling with delete-and-retry logic\n- File size validation (500MB limit)\n- Comprehensive error handling with custom error types\n- Support for multiple tenant configurations\n- Built-in retry logic and configurable timeouts\n- Full test coverage with mocked HTTP interactions","ref":"readme.html#features"},{"type":"extras","title":"Installation - QlikElixir","doc":"Add `qlik_elixir` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:qlik_elixir, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - QlikElixir","doc":"","ref":"readme.html#configuration"},{"type":"extras","title":"Environment Variables - QlikElixir","doc":"The simplest way to configure QlikElixir is through environment variables:\n\n```bash\nexport QLIK_API_KEY=\"your-api-key\"\nexport QLIK_TENANT_URL=\"https://your-tenant.qlikcloud.com\"\nexport QLIK_CONNECTION_ID=\"your-connection-id\"  # Optional\n```","ref":"readme.html#environment-variables"},{"type":"extras","title":"Application Configuration - QlikElixir","doc":"You can also configure it in your `config/config.exs`:\n\n```elixir\nconfig :qlik_elixir,\n  api_key: \"your-api-key\",\n  tenant_url: \"https://your-tenant.qlikcloud.com\",\n  connection_id: \"your-connection-id\"  # Optional\n```","ref":"readme.html#application-configuration"},{"type":"extras","title":"Runtime Configuration - QlikElixir","doc":"For runtime configuration or multiple tenants:\n\n```elixir\nconfig = QlikElixir.new_config(\n  api_key: \"different-key\",\n  tenant_url: \"https://other-tenant.qlikcloud.com\",\n  connection_id: \"space-123\",\n  http_options: [timeout: 60_000]  # 1 minute timeout\n)\n\nQlikElixir.upload_csv(\"data.csv\", config: config)\n```","ref":"readme.html#runtime-configuration"},{"type":"extras","title":"Usage - QlikElixir","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic File Upload - QlikElixir","doc":"```elixir\n# Upload a CSV file\n{:ok, %{\"id\" => file_id}} = QlikElixir.upload_csv(\"path/to/data.csv\")\n\n# Upload with custom name\n{:ok, file} = QlikElixir.upload_csv(\"data.csv\", name: \"renamed_file.csv\")\n\n# Upload with overwrite\n{:ok, file} = QlikElixir.upload_csv(\"data.csv\", overwrite: true)\n\n# Upload to specific connection\n{:ok, file} = QlikElixir.upload_csv(\"data.csv\", connection_id: \"space-123\")\n```","ref":"readme.html#basic-file-upload"},{"type":"extras","title":"Upload Content Directly - QlikElixir","doc":"```elixir\n# Create CSV content dynamically\ncsv_content = \"id,name,email\\n1,John Doe,john@example.com\\n2,Jane Smith,jane@example.com\"\n\n# Upload the content\n{:ok, file} = QlikElixir.upload_csv_content(csv_content, \"users.csv\")\n\n# With options\n{:ok, file} = QlikElixir.upload_csv_content(\n  csv_content, \n  \"users.csv\",\n  connection_id: \"space-456\",\n  overwrite: true\n)\n```","ref":"readme.html#upload-content-directly"},{"type":"extras","title":"List Files - QlikElixir","doc":"```elixir\n# List all files (up to 100)\n{:ok, %{\"data\" => files, \"total\" => total}} = QlikElixir.list_files()\n\n# With pagination\n{:ok, result} = QlikElixir.list_files(limit: 20, offset: 40)\n```","ref":"readme.html#list-files"},{"type":"extras","title":"Check File Existence - QlikElixir","doc":"```elixir\n# Check if a file exists by name\nif QlikElixir.file_exists?(\"important_data.csv\") do\n  IO.puts(\"File already exists!\")\nend\n```","ref":"readme.html#check-file-existence"},{"type":"extras","title":"Find File by Name - QlikElixir","doc":"```elixir\ncase QlikElixir.find_file_by_name(\"sales_data.csv\") do\n  {:ok, file} ->\n    IO.puts(\"Found file with ID: #{file[\"id\"]}\")\n  \n  {:error, _} ->\n    IO.puts(\"File not found\")\nend\n```","ref":"readme.html#find-file-by-name"},{"type":"extras","title":"Delete Files - QlikElixir","doc":"```elixir\n# Delete by file ID\ncase QlikElixir.delete_file(\"file-id-123\") do\n  :ok ->\n    IO.puts(\"File deleted successfully\")\n  \n  {:error, error} ->\n    IO.puts(\"Failed to delete: #{error.message}\")\nend\n```","ref":"readme.html#delete-files"},{"type":"extras","title":"Advanced Usage - QlikElixir","doc":"","ref":"readme.html#advanced-usage"},{"type":"extras","title":"Custom Configuration per Request - QlikElixir","doc":"```elixir\n# Create a custom config for a specific tenant\neu_config = QlikElixir.new_config(\n  api_key: System.get_env(\"EU_QLIK_API_KEY\"),\n  tenant_url: \"https://eu-tenant.qlikcloud.com\"\n)\n\n# Use it for specific operations\n{:ok, file} = QlikElixir.upload_csv(\"eu_data.csv\", config: eu_config)\n{:ok, files} = QlikElixir.list_files(config: eu_config)\n```","ref":"readme.html#custom-configuration-per-request"},{"type":"extras","title":"Error Handling - QlikElixir","doc":"QlikElixir provides detailed error information:\n\n```elixir\ncase QlikElixir.upload_csv(\"data.csv\") do\n  {:ok, file} ->\n    IO.puts(\"Uploaded successfully: #{file[\"id\"]}\")\n  \n  {:error, %QlikElixir.Error{} = error} ->\n    case error.type do\n      :file_exists_error ->\n        IO.puts(\"File already exists. Use overwrite: true to replace it.\")\n      \n      :file_too_large ->\n        IO.puts(\"File is too large. Maximum size is 500MB.\")\n      \n      :authentication_error ->\n        IO.puts(\"Invalid API key. Please check your configuration.\")\n      \n      :validation_error ->\n        IO.puts(\"Validation failed: #{error.message}\")\n      \n      _ ->\n        IO.puts(\"Upload failed: #{error.message}\")\n    end\nend\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"Batch Operations - QlikElixir","doc":"```elixir\n# Upload multiple files\nfiles = [\"data1.csv\", \"data2.csv\", \"data3.csv\"]\n\nresults = Enum.map(files, fn file ->\n  case QlikElixir.upload_csv(file) do\n    {:ok, result} -> {:ok, file, result[\"id\"]}\n    {:error, error} -> {:error, file, error}\n  end\nend)\n\n# Process results\nEnum.each(results, fn\n  {:ok, file, id} -> IO.puts(\"✓ #{file} uploaded as #{id}\")\n  {:error, file, error} -> IO.puts(\"✗ #{file} failed: #{error.message}\")\nend)\n```","ref":"readme.html#batch-operations"},{"type":"extras","title":"Progress Monitoring - QlikElixir","doc":"For large file uploads, you might want to show progress:\n\n```elixir\ndefmodule UploadProgress do\n  def upload_with_progress(file_path) do\n    %{size: file_size} = File.stat!(file_path)\n    \n    IO.puts(\"Uploading #{Path.basename(file_path)} (#{format_bytes(file_size)})...\")\n    \n    case QlikElixir.upload_csv(file_path) do\n      {:ok, result} ->\n        IO.puts(\"✓ Upload complete! File ID: #{result[\"id\"]}\")\n        {:ok, result}\n      \n      {:error, error} ->\n        IO.puts(\"✗ Upload failed: #{error.message}\")\n        {:error, error}\n    end\n  end\n  \n  defp format_bytes(bytes) when bytes < 1024, do: \"#{bytes} B\"\n  defp format_bytes(bytes) when bytes < 1024 * 1024, do: \"#{Float.round(bytes / 1024, 1)} KB\"\n  defp format_bytes(bytes), do: \"#{Float.round(bytes / (1024 * 1024), 1)} MB\"\nend\n```","ref":"readme.html#progress-monitoring"},{"type":"extras","title":"HTTP Options - QlikElixir","doc":"You can customize HTTP behavior through configuration:\n\n```elixir\nconfig = QlikElixir.new_config(\n  api_key: \"your-key\",\n  tenant_url: \"https://your-tenant.qlikcloud.com\",\n  http_options: [\n    timeout: :timer.minutes(10),     # 10 minute timeout for large files\n    retry: :transient,               # Retry on transient errors\n    max_retries: 5,                  # Maximum number of retries\n    retry_delay: fn n -> n * 2000 end # Exponential backoff\n  ]\n)\n```","ref":"readme.html#http-options"},{"type":"extras","title":"Error Types - QlikElixir","doc":"QlikElixir defines the following error types:\n\n- `:validation_error` - Invalid input parameters\n- `:upload_error` - General upload failure\n- `:authentication_error` - Invalid or missing API key\n- `:configuration_error` - Invalid configuration\n- `:file_exists_error` - File already exists (when overwrite is false)\n- `:file_not_found` - File or resource not found\n- `:file_too_large` - File exceeds 500MB limit\n- `:network_error` - Network connectivity issues\n- `:unknown_error` - Unexpected errors","ref":"readme.html#error-types"},{"type":"extras","title":"Testing - QlikElixir","doc":"Run the test suite:\n\n```bash\nmix test\n```\n\nRun with coverage:\n\n```bash\nmix coveralls.html\n```","ref":"readme.html#testing"},{"type":"extras","title":"Contributing - QlikElixir","doc":"1. Fork the repository\n2. Create your feature branch (`git checkout -b feature/amazing-feature`)\n3. Commit your changes (`git commit -m 'Add some amazing feature'`)\n4. Push to the branch (`git push origin feature/amazing-feature`)\n5. Open a Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - QlikElixir","doc":"This project is licensed under the MIT License - see the LICENSE file for details.","ref":"readme.html#license"},{"type":"extras","title":"Acknowledgments - QlikElixir","doc":"- Built with [Req](https://hexdocs.pm/req) for HTTP client functionality\n- Inspired by the Qlik Cloud API documentation\n- Thanks to the Elixir community for the amazing ecosystem","ref":"readme.html#acknowledgments"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]\n\n## [0.1.0] - 2024-01-01","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release of QlikElixir\n- Core upload functionality for CSV files to Qlik Cloud\n- Support for file path and binary content uploads\n- Automatic overwrite handling with delete-and-retry logic\n- File size validation (500MB limit)\n- Comprehensive error handling with custom error types\n- List files with pagination support\n- Delete files by ID\n- Check file existence by name\n- Find file by name\n- Support for environment variables configuration\n- Support for runtime configuration override\n- Support for multiple tenant configurations\n- Configurable HTTP client options (timeout, retry)\n- Full test coverage with Bypass for HTTP mocking\n- Comprehensive documentation and examples\n\n[Unreleased]: https://github.com/yourusername/qlik_elixir/compare/v0.1.0...HEAD\n[0.1.0]: https://github.com/yourusername/qlik_elixir/releases/tag/v0.1.0","ref":"changelog.html#added"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}